<?php
/**
 * Internationalisation file for Poem extension.
 *
 * @file
 * @ingroup Extensions
 */

$messages = array();

$messages['en'] = array(
	'poem-desc' => 'Adds <code>&lt;poem&gt;</code> tag for poem formatting',
);

/** Message documentation (Message documentation)
 * @author Raymond
 */
$messages['qqq'] = array(
	'poem-desc' => 'Extension description displayed on [[Special:Version]]',
);

/** Afrikaans (Afrikaans)
 * @author Naudefj
 */
$messages['af'] = array(
	'poem-desc' => "Maak 'n <code>&lt;poem&gt;</code> etiket beskikbaar vir die formatering van poësie",
);

/** Aragonese (aragonés)
 * @author Juanpabl
 */
$messages['an'] = array(
	'poem-desc' => 'Adibe a etiqueta <code>&lt;poem&gt;</code> ta formateyar poesía',
);

/** Arabic (العربية)
 * @author Meno25
 */
$messages['ar'] = array(
	'poem-desc' => 'يضيف الوسم <code>&lt;poem&gt;</code> لصياغة القصيدة',
);

/** Egyptian Spoken Arabic (مصرى)
 * @author Ramsis II
 */
$messages['arz'] = array(
	'poem-desc' => 'بيضيف تاج ال <code>&lt;poem&gt;</code> لصياغة القصيدة',
);

/** Asturian (asturianu)
 * @author Esbardu
 */
$messages['ast'] = array(
	'poem-desc' => 'Añade la etiqueta <code>&lt;poem&gt;</code> pal formatu de poemes',
);

/** Azerbaijani (azərbaycanca)
 * @author Sortilegus
 */
$messages['az'] = array(
	'poem-desc' => 'Şeirlərin formatlaşdırılması üçün <code>&lt;poem&gt;</code> teqini əlavə edir',
);

/** Bashkir (башҡортса)
 * @author Assele
 */
$messages['ba'] = array(
	'poem-desc' => 'Шиғырҙарҙы форматлау өсөн <code>&lt;poem&gt;</code> билдәһен өҫтәй',
);

/** Bavarian (Boarisch)
 * @author Man77
 */
$messages['bar'] = array(
	'poem-desc' => "Fügt s'<code>&lt;poem&gt;</code>-Tag zum Formatian vu Gedichtln dazua",
);

/** Southern Balochi (بلوچی مکرانی)
 * @author Mostafadaneshvar
 */
$messages['bcc'] = array(
	'poem-desc' => 'هورکنت <code>&lt;poem&gt;</code> برچسپء په فرمت شئر',
);

/** Belarusian (Taraškievica orthography) (беларуская (тарашкевіца)‎)
 * @author Jim-by
 */
$messages['be-tarask'] = array(
	'poem-desc' => 'Дадае тэг <code>&lt;poem&gt;</code> для фарматаваньня вершаў',
);

/** Bulgarian (български)
 * @author DCLXVI
 */
$messages['bg'] = array(
	'poem-desc' => 'Добавя етикет <code>&lt;poem&gt;</code> за форматиране на стихове',
);

/** Bengali (বাংলা)
 * @author Bellayet
 */
$messages['bn'] = array(
	'poem-desc' => 'কবিতার ফরমেটিং এর জন্য <code>&lt;poem&gt;</code> ট্যাগ যোগ করুন',
);

/** Breton (brezhoneg)
 * @author Fulup
 */
$messages['br'] = array(
	'poem-desc' => 'Ouzhpennañ a ra ar valizenn <code>&lt;poem&gt;</code> da furmadiñ testennoù barzhonegoù.',
);

/** Bosnian (bosanski)
 * @author CERminator
 */
$messages['bs'] = array(
	'poem-desc' => 'Dodaje oznaku <code>&lt;poem&gt;</code> za formatiranje stihova',
);

/** Catalan (català)
 * @author Paucabot
 */
$messages['ca'] = array(
	'poem-desc' => "Afegeix l'etiqueta <code>&lt;poem&gt;</code> per al formatatge  de poemes",
);

/** Sorani Kurdish (کوردی)
 * @author Asoxor
 */
$messages['ckb'] = array(
	'poem-desc' => 'تاگی <code>&lt;poem&gt;</code> زێدەدەکات بۆ ڕێکخستنی ھۆنراوەکان',
);

/** Czech (česky)
 * @author Matěj Grabovský
 */
$messages['cs'] = array(
	'poem-desc' => 'Přidává značku <code>&lt;poem&gt;</code> pro formátování básní',
);

/** Danish (dansk)
 * @author Peter Alberti
 */
$messages['da'] = array(
	'poem-desc' => 'Tilføjer tagget <code>&lt;poem&gt;</code> til formatering af digte',
);

/** German (Deutsch)
 * @author Kghbln
 * @author Raimond Spekking
 */
$messages['de'] = array(
	'poem-desc' => 'Ergänzt das Tag <code>&lt;poem&gt;</code> zur Formatierung von Gedichten',
);

/** Zazaki (Zazaki)
 * @author Aspar
 */
$messages['diq'] = array(
	'poem-desc' => 'qey fesaldayişê şiiri etiketê <code>&lt;poem&gt;</code>i têarê keno',
);

/** Lower Sorbian (dolnoserbski)
 * @author Michawiki
 */
$messages['dsb'] = array(
	'poem-desc' => 'Pśidawa toflicku <code>&lt;poem&gt;</code> za formatěrowanje basnjow',
);

/** Greek (Ελληνικά)
 * @author Dead3y3
 */
$messages['el'] = array(
	'poem-desc' => 'Προσθέτει την ετικέτα <code>&lt;poem&gt;</code> για την μορφοποίηση ποιημάτων',
);

/** Esperanto (Esperanto)
 * @author Yekrats
 */
$messages['eo'] = array(
	'poem-desc' => 'Aldonas <code>&lt;poem&gt;</code> etikedon por formatado de poezio.',
);

/** Spanish (español)
 * @author Muro de Aguas
 */
$messages['es'] = array(
	'poem-desc' => 'Añade la etiqueta <code>&lt;poem&gt;</code> para dar el formato propio de un poema.',
);

/** Estonian (eesti)
 * @author Pikne
 */
$messages['et'] = array(
	'poem-desc' => 'Lisab <code>&lt;poem&gt;</code>-sildi luuletuse vormindamiseks.',
);

/** Basque (euskara)
 * @author Theklan
 */
$messages['eu'] = array(
	'poem-desc' => '<code>&lt;poem&gt;</code> etiketa gehitzen du olerkien formaturako',
);

/** Persian (فارسی)
 * @author Huji
 */
$messages['fa'] = array(
	'poem-desc' => 'برچسب <code>&lt;poem&gt;</code> را برای قالب‌بندی شعرها می‌افزاید',
);

/** Finnish (suomi)
 * @author Nike
 */
$messages['fi'] = array(
	'poem-desc' => 'Mahdollistaa runojen muotoilun <code>&lt;poem&gt;</code>-elementillä.',
);

/** French (français)
 * @author Grondin
 */
$messages['fr'] = array(
	'poem-desc' => 'Ajoute la balise <code>&lt;poem&gt;</code> pour le formatage des poèmes',
);

/** Franco-Provençal (arpetan)
 * @author ChrisPtDe
 */
$messages['frp'] = array(
	'poem-desc' => 'Apond la balisa <code>&lt;poem&gt;</code> por lo formatâjo des poèmos.',
);

/** Northern Frisian (Nordfriisk)
 * @author Murma174
 */
$messages['frr'] = array(
	'poem-desc' => 'Saat <code>&lt;poem&gt;</code> diartu, am dachtangen tu formatiarin',
);

/** Galician (galego)
 * @author Alma
 */
$messages['gl'] = array(
	'poem-desc' => 'Engada a etiqueta <code>&lt;poem&gt;</code> para o formato poema',
);

/** Swiss German (Alemannisch)
 * @author Als-Holder
 */
$messages['gsw'] = array(
	'poem-desc' => 'Fiegt s <code>&lt;poem&gt;</code>-Tag zue zum Formatiere vu Gedicht',
);

/** Hebrew (עברית)
 */
$messages['he'] = array(
	'poem-desc' => 'הוספת התגית <code>&lt;poem&gt;</code> לעיצוב שירה',
);

/** Hindi (हिन्दी)
 * @author Kaustubh
 */
$messages['hi'] = array(
	'poem-desc' => 'कविता लिखने के लिये आवश्यक <code>&lt;poem&gt;</code> टॅग देता हैं',
);

/** Hiligaynon (Ilonggo)
 * @author Tagimata
 */
$messages['hil'] = array(
	'poem-desc' => 'Gadugang <code>&lt;poem&gt;</code> tag para sa pagformat sang tula',
);

/** Croatian (hrvatski)
 * @author Dalibor Bosits
 */
$messages['hr'] = array(
	'poem-desc' => 'Dodaje <code>&lt;poem&gt;</code> oznaku za formatiranje pjesama',
);

/** Upper Sorbian (hornjoserbsce)
 * @author Michawiki
 */
$messages['hsb'] = array(
	'poem-desc' => 'Přidawa tafličku <code>&lt;poem&gt;</code> za formatowanje basnjow',
);

/** Hungarian (magyar)
 * @author Dani
 */
$messages['hu'] = array(
	'poem-desc' => '<code>&lt;poem&gt;</code> tag a versek formázásához',
);

/** Interlingua (interlingua)
 * @author McDutchie
 */
$messages['ia'] = array(
	'poem-desc' => 'Adde le etiquetta <code>&lt;poem&gt;</code> pro formatar poemas',
);

/** Indonesian (Bahasa Indonesia)
 * @author IvanLanin
 */
$messages['id'] = array(
	'poem-desc' => 'Menambahkan tag <code>&lt;poem&gt;</code> tag untuk pemformatan puisi',
);

/** Iloko (Ilokano)
 * @author Lam-ang
 */
$messages['ilo'] = array(
	'poem-desc' => 'Ikkan na iti<code>&lt;poem&gt;</code> nga tag para ti pagporma ti daniw',
);

/** Italian (italiano)
 * @author BrokenArrow
 */
$messages['it'] = array(
	'poem-desc' => 'Aggiunge il tag <code>&lt;poem&gt;</code> per la formattazione dei testi poetici',
);

/** Japanese (日本語)
 * @author Aotake
 * @author JtFuruhata
 * @author Shirayuki
 */
$messages['ja'] = array(
	'poem-desc' => '詩を整形する <code>&lt;poem&gt;</code> タグを追加する',
);

/** Jutish (jysk)
 * @author Huslåke
 */
$messages['jut'] = array(
	'poem-desc' => 'Tilføje <code>&lt;poem&gt;</code> tag før digt formåter',
);

/** Javanese (Basa Jawa)
 * @author Meursault2004
 */
$messages['jv'] = array(
	'poem-desc' => 'Nambahaké tag <code>&lt;poem&gt;</code> tag kanggo formatting tembang utawa puisi',
);

/** Georgian (ქართული)
 * @author David1010
 */
$messages['ka'] = array(
	'poem-desc' => 'ამატებს ტეგს <code>&lt;პოემა&gt;</code> ლექსების ფორმატირებისათვის',
);

/** Khmer (ភាសាខ្មែរ)
 * @author Lovekhmer
 * @author Thearith
 */
$messages['km'] = array(
	'poem-desc' => 'ដាក់ប្លាក <code>&lt;poem&gt;</code> សម្រាប់ទ្រង់ទ្រាយកំណាព្យ',
);

/** Korean (한국어)
 * @author ToePeu
 * @author 아라
 */
$messages['ko'] = array(
	'poem-desc' => '시 형식을 위해 <code>&lt;poem&gt;</code> 태그를 추가합니다',
);

/** Colognian (Ripoarisch)
 * @author Purodha
 */
$messages['ksh'] = array(
	'poem-desc' => 'Brengk et <code>&lt;poem&gt;</code>-Kommando met, för Jedeeshte ze jeshtallde.',
);

/** Luxembourgish (Lëtzebuergesch)
 * @author Robby
 */
$messages['lb'] = array(
	'poem-desc' => "Setzt de <code>&lt;poem&gt;</code>-Tag fir d'Formatéierung vu Gedichter derbäi",
);

/** Limburgish (Limburgs)
 * @author Matthias
 */
$messages['li'] = array(
	'poem-desc' => 'Voegt de tag <code>&lt;poem&gt;</code> toe veur de opmaak van poëzie',
);

/** Lithuanian (lietuvių)
 * @author Garas
 * @author Hugo.arg
 */
$messages['lt'] = array(
	'poem-desc' => 'Prideda <code>&lt;poem&gt;</code> gaires poemų formatavimui',
);

/** Mizo (Mizo ţawng)
 * @author RMizo
 */
$messages['lus'] = array(
	'poem-desc' => 'Hlahril tàrphung siamrem  nan tàrreuh  <code>&lt;poem&gt;</code>   hi a belh.',
);

/** Latvian (latviešu)
 * @author Papuass
 * @author Xil
 */
$messages['lv'] = array(
	'poem-desc' => 'Pievieno <code>&lt;poem&gt;</code> iezīmi dzejas formatēšanai',
);

/** Macedonian (македонски)
 * @author Bjankuloski06
 * @author Brest
 */
$messages['mk'] = array(
	'poem-desc' => 'Додава <code>&lt;poem&gt;</code> ознака за форматирање на стихови',
);

/** Malayalam (മലയാളം)
 * @author Shijualex
 */
$messages['ml'] = array(
	'poem-desc' => 'പദ്യത്തിന്റെ ഫോർമാറ്റിങ്ങിനു <code>&lt;poem&gt;</code>  എന്ന ടാഗ് ചേർക്കുന്നു',
);

/** Marathi (मराठी)
 * @author Kaustubh
 */
$messages['mr'] = array(
	'poem-desc' => 'कवितेच्या सादरीकरणासाठी आवश्यक असणारा <code>&lt;poem&gt;</code> टॅग देतो.',
);

/** Malay (Bahasa Melayu)
 * @author Aviator
 */
$messages['ms'] = array(
	'poem-desc' => 'Menambah tag <code>&lt;poem&gt;</code> untuk pemformatan puisi',
);

/** Norwegian Bokmål (norsk bokmål)
 */
$messages['nb'] = array(
	'poem-desc' => 'Legger til taggen <code>&lt;poem&gt;</code> for å kunne formatere dikt',
);

/** Low German (Plattdüütsch)
 * @author Slomox
 */
$messages['nds'] = array(
	'poem-desc' => 'Föögt dat <code>&lt;poem&gt;</code>-Tag för dat Formateren vun Gedichten to',
);

/** Dutch (Nederlands)
 * @author Siebrand
 */
$messages['nl'] = array(
	'poem-desc' => 'Voegt de tag <code>&lt;poem&gt;</code> toe voor de opmaak van poëzie',
);

/** Norwegian Nynorsk (norsk nynorsk)
 * @author Harald Khan
 */
$messages['nn'] = array(
	'poem-desc' => 'Legg til merket <code>&lt;poem&gt;</code> for å kunna formatera dikt',
);

/** Occitan (occitan)
 * @author Cedric31
 */
$messages['oc'] = array(
	'poem-desc' => 'Apond la balisa <code>&lt;poem&gt;</code> pel formatatge dels poèmas',
);

/** Polish (polski)
 * @author Sp5uhe
 */
$messages['pl'] = array(
	'poem-desc' => 'Dodaje znacznik <code>&lt;poem&gt;</code> służący do formatowania wierszy',
);

/** Piedmontese (Piemontèis)
 * @author Dragonòt
 */
$messages['pms'] = array(
	'poem-desc' => 'A gionta ël tag <code>&lt;poem&gt;</code> për formatassion ëd poema',
);

/** Pashto (پښتو)
 * @author Ahmed-Najib-Biabani-Ibrahimkhel
 */
$messages['ps'] = array(
	'poem-desc' => 'د شعر بڼه ورکولو کړنې لپاره د <tt>&lt;شعر&gt;</tt> وييکه ورگډوي',
);

/** Portuguese (português)
 * @author Hamilton Abreu
 * @author Malafaya
 */
$messages['pt'] = array(
	'poem-desc' => 'Adiciona o elemento <code>&lt;poem&gt;</code> para formatação de poemas',
);

/** Brazilian Portuguese (português do Brasil)
 * @author Eduardo.mps
 */
$messages['pt-br'] = array(
	'poem-desc' => 'Adiciona a marca <code>&lt;poem&gt;</code> para formatação de poemas',
);

/** Tarifit (Tarifit)
 * @author Aryaz
 */
$messages['rif'] = array(
	'poem-desc' => 'Issadaf <code>&lt;poem&gt;</code> i usmal d tira n tmdyazt',
);

/** Romanian (română)
 * @author Mihai
 */
$messages['ro'] = array(
	'poem-desc' => 'Adaugă eticheta <code>&lt;poem&gt;</code> pentru formatarea poem',
);

/** tarandíne (tarandíne)
 * @author Joetaras
 */
$messages['roa-tara'] = array(
	'poem-desc' => "Aggiunge 'u tag <code>&lt;poem&gt;</code> p'a formattazione de le poesie",
);

/** Russian (русский)
 * @author Александр Сигачёв
 */
$messages['ru'] = array(
	'poem-desc' => 'Добавляет тег <code>&lt;poem&gt;</code> для форматирования стихов',
);

/** Rusyn (русиньскый)
 * @author Gazeb
 */
$messages['rue'] = array(
	'poem-desc' => 'Додасть значку <code>&lt;poem&gt;</code> про форматованя віршів',
);

/** Sakha (саха тыла)
 * @author HalanTul
 */
$messages['sah'] = array(
	'poem-desc' => 'Хоһооннору суруйарга <code>&lt;poem&gt;</code> тиэги эбэр',
);

/** Sicilian (sicilianu)
 * @author Melos
 */
$messages['scn'] = array(
	'poem-desc' => 'Iunci lu tag <code>&lt;poem&gt;</code> pi la furmattazioni di li testa puetici',
);

/** Slovak (slovenčina)
 * @author Helix84
 */
$messages['sk'] = array(
	'poem-desc' => 'Pridáva značku <code>&lt;poem&gt;</code> pre formátovanie básní',
);

/** Slovenian (slovenščina)
 * @author Dbc334
 */
$messages['sl'] = array(
	'poem-desc' => 'Doda etiketo <code>&lt;poem&gt;</code> za oblikovanje pesmi',
);

/** Lower Silesian (Schläsch)
 * @author Piotron
 */
$messages['sli'] = array(
	'poem-desc' => 'Fiegt is <code>&lt;poem&gt;</code>-Tag zur Furmatierung voo Gedichta hinzu',
);

/** Albanian (shqip)
 * @author Puntori
 */
$messages['sq'] = array(
	'poem-desc' => 'Vendosë kodin <code>&lt;poem&gt;</code> për formatim të poezive',
);

/** Serbian (Cyrillic script) (српски (ћирилица)‎)
 * @author Millosh
 * @author Nikola Smolenski
 */
$messages['sr-ec'] = array(
	'poem-desc' => 'Додаје <code>&lt;poem&gt;</code> ознаку за форматирање песама.',
);

/** Serbian (Latin script) (srpski (latinica)‎)
 * @author Michaello
 */
$messages['sr-el'] = array(
	'poem-desc' => 'Dodaje <code>&lt;poem&gt;</code> oznaku za formatiranje pesama.',
);

/** Seeltersk (Seeltersk)
 * @author Pyt
 */
$messages['stq'] = array(
	'poem-desc' => 'Föiget dät <code>&lt;poem&gt;</code>-Tag tou ju Formatierenge fon Gedichte bietou',
);

/** Swedish (svenska)
 * @author Lejonel
 */
$messages['sv'] = array(
	'poem-desc' => 'Lägger till taggen <code>&lt;poem&gt;</code> för att formatera dikter',
);

/** Telugu (తెలుగు)
 * @author Veeven
 */
$messages['te'] = array(
	'poem-desc' => 'పద్యాల ఫార్మాటింగుకై <code>&lt;poem&gt;</code> అనే టాగుని చేరుస్తుంది',
);

/** Tajik (Cyrillic script) (тоҷикӣ)
 * @author Ibrahim
 */
$messages['tg-cyrl'] = array(
	'poem-desc' => 'Барчасби <code>&lt;poem&gt;</code>-ро барои қолаббандиҳои шеърҳо илова мекунад',
);

/** Tajik (Latin script) (tojikī)
 * @author Liangent
 */
$messages['tg-latn'] = array(
	'poem-desc' => "Barcasbi <code>&lt;poem&gt;</code>-ro baroi qolabbandihoi şe'rho ilova mekunad",
);

/** Thai (ไทย)
 * @author Octahedron80
 */
$messages['th'] = array(
	'poem-desc' => 'เพิ่มแท็ก <code>&lt;poem&gt;</code> สำหรับการจัดรูปแบบบทกวี',
);

/** Turkmen (Türkmençe)
 * @author Hanberke
 */
$messages['tk'] = array(
	'poem-desc' => 'Goşgy formatirlemesi üçin <code>&lt;poem&gt;</code> tegini goşýar',
);

/** Tagalog (Tagalog)
 * @author AnakngAraw
 */
$messages['tl'] = array(
	'poem-desc' => 'Nagdaragdag ng tatak na <code>&lt;poem&gt;</code> para sa pagpopormat ng tula',
);

/** Turkish (Türkçe)
 * @author Joseph
 */
$messages['tr'] = array(
	'poem-desc' => 'Şiir biçimlendirmesi için <code>&lt;poem&gt;</code> etiketini ekler',
);

/** Ukrainian (українська)
 * @author Ahonc
 */
$messages['uk'] = array(
	'poem-desc' => 'Додає тег <code>&lt;poem&gt;</code> для форматування віршів',
);

/** vèneto (vèneto)
 * @author Candalua
 */
$messages['vec'] = array(
	'poem-desc' => 'Zonta el tag <code>&lt;poem&gt;</code> par la formatazion dei testi poetici',
);

/** Veps (vepsän kel’)
 * @author Игорь Бродский
 */
$messages['vep'] = array(
	'poem-desc' => 'Ližadab <code>&lt;poem&gt;</code>-virg runod formatiruides',
);

/** Vietnamese (Tiếng Việt)
 * @author Minh Nguyen
 */
$messages['vi'] = array(
	'poem-desc' => 'Thêm thẻ <code>&lt;poem&gt;</code> để định dạng các bài thơ',
);

/** Volapük (Volapük)
 * @author Smeira
 */
$messages['vo'] = array(
	'poem-desc' => 'Läükon mali: <code>&lt;poem&gt;</code> pro fomät: poedot',
);

/** Cantonese (粵語)
 * @author Shinjiman
 */
$messages['yue'] = array(
	'poem-desc' => '加 <code>&lt;poem&gt;</code> 標籤畀詩格式用',
);

/** Simplified Chinese (中文（简体）‎)
 * @author Shinjiman
 * @author Wmr89502270
 * @author Xiaomingyan
 */
$messages['zh-hans'] = array(
	'poem-desc' => '添加“<code>&lt;poem&gt;</code>”标签用于诗歌格式',
);

/** Traditional Chinese (中文（繁體）‎)
 * @author Shinjiman
 */
$messages['zh-hant'] = array(
	'poem-desc' => '加入 <code>&lt;poem&gt;</code> 標籤給予詩歌格式使用',
);
